# lapa_authentication_helper

## about

helper to access the authentication service.

## installation

> pip install lapa_authentication_helper

## usage

[reference python file](./example.py)

## configs

1. lapa_authentication_helper\data\config.ini

## env

- python>=3.12.0

## changelog

### v0.0.1

- initial implementation.

## Feedback is appreciated. Thank you!
